@@ -935,15 +935,6 @@ function pulsateStop(element) {
 }
 
 $(function() {
-	clearTimeout(messageTimer);
-
-	$('#message_container').show();
-
-	messageTimer = setTimeout(function() { 
-		$('#message_container').slideUp('fast'); 
-		$('#message_container').empty(); 
-	}, 6000);
-
 	setupUserMenu();
 
 	applySkin();
