@@ -290,7 +290,7 @@ class Net_Ping
 		$this->time = $this->get_time($this->precision);
 
 		/* check result for uptime */
-		if ($output !== false && strlen($output)) {
+		if ($output !== false && $output != 'U' && strlen($output)) {
 			/* calculte total time */
 			$this->snmp_status   = $this->time*1000;
 			$this->snmp_response = 'Device responded to SNMP';
